@@ -18,7 +18,7 @@ position_dodge2nudge <-
 
     fun_one <- function(x) {1}
 
-    ggplot2::ggproto(NULL, PositionDodgeAndNudge,
+    ggplot2::ggproto(NULL, PositionDodge2AndNudge,
                      x = x,
                      y = y,
                      .fun_x = switch(direction,
@@ -45,21 +45,32 @@ position_dodge2nudge <-
 #' @format NULL
 #' @usage NULL
 #' @noRd
-PositionDodgeAndNudge <-
-  ggplot2::ggproto("PositionDodgeAndNudge", ggplot2::PositionDodge2,
+PositionDodge2AndNudge <-
+  ggplot2::ggproto("PositionDodge2AndNudge", ggplot2::PositionDodge2,
                    x = 0,
                    y = 0,
 
                    setup_params = function(self, data) {
                      c(
-                       list(nudge_x = self$x, nudge_y = self$y,
-                            .fun_x = self$.fun_x, .fun_y = self$.fun_y,
+                       list(nudge_x = self$x,
+                            nudge_y = self$y,
+                            .fun_x = self$.fun_x,
+                            .fun_y = self$.fun_y,
+                            x.reorder = !is.null(self$x) && length(self$x) > 1 && length(self$x) < nrow(data),
+                            y.reorder = !is.null(self$y) && length(self$y) > 1 && length(self$y) < nrow(data),
                             kept.origin = self$kept.origin),
                        ggplot2::ggproto_parent(ggplot2::PositionDodge2, self)$setup_params(data)
                      )
                    },
 
                    compute_layer = function(self, data, params, layout) {
+
+                     if (length(params$nudge_x) > nrow(data)) {
+                       warning("Argument 'x' longer than data: some values dropped!")
+                     }
+                     if (length(params$nudge_y) > nrow(data)) {
+                       warning("Argument 'y' longer than data: some values dropped!")
+                     }
                      x_orig <- data$x
                      y_orig <- data$y
                      # operate on the dodged positions
@@ -67,6 +78,18 @@ PositionDodgeAndNudge <-
 
                      x_dodged <- data$x
                      y_dodged <- data$y
+
+                     if (params$x.reorder) {
+                       params$nudge_x <- rep_len(params$nudge_x, nrow(data))[order(order(data$x))]
+                     } else {
+                       params$nudge_x <- rep_len(params$nudge_x, nrow(data))
+                     }
+                     if (params$y.reorder) {
+                       params$nudge_y <- rep_len(params$nudge_y, nrow(data))[order(order(data$y))]
+                     } else {
+                       params$nudge_y <- rep_len(params$nudge_y, nrow(data))
+                     }
+
                      # transform only the dimensions for which non-zero nudging is requested
                      if (any(params$nudge_x != 0)) {
                        if (any(params$nudge_y != 0)) {
